@@ -441,6 +441,8 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
     ######   MARGINAL ESTIMATED TRAJECTORIES            ######
     ######   FOR THE MOST COMMON PROFILE OF COVARIATES  ######
     ##########################################################
+    dataset = dataset2
+    #
     if(traj.marg == TRUE){
       if (mean(dataset[,time]) > 0){
         min_plot = round(quantile(dataset[,time], probs=c(0.01)),0)
@@ -453,9 +455,9 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
       tab_traj = data.frame(time = seq(min_plot, max_plot, 0.1),
                             ## parameters
                             last.level  = coef.PMM[1],
-                            slope1      = coef.PMM[1*length(var.all)+length(var.last.level) + 2],
-                            slope2      = coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3],
-                            changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4],
+                            slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2],
+                            slope2      = coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3],
+                            changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4],
                             ## transition parameter
                             transition = 2)
 
@@ -501,9 +503,9 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
       tab_traj = data.frame(time = seq(min_plot, max_plot, 0.1),
                             ## parameters
                             last.level  = coef.PMM[1],
-                            slope1      = coef.PMM[1*length(var.all)+length(var.last.level) + 2],
-                            slope2      = coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3],
-                            changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4],
+                            slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2],
+                            slope2      = coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3],
+                            changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4],
                             ## transition parameter
                             transition = 2)
 
@@ -518,17 +520,17 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
       tab_traj = data.frame(time = seq(min_plot, max_plot, 0.1), transition = 2)
       ##
       tab_traj$last.level  = coef.PMM[1] + coef.PMM[1+pos_raw]*mat_predictor[pos_raw,1]
-      tab_traj$slope1      = coef.PMM[1*length(var.all)+length(var.last.level) + 2] + coef.PMM[1*length(var.all)+length(var.last.level) + 2 + pos_raw]*mat_predictor[pos_raw,2]
-      tab_traj$slope2      = coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3] + coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3 + pos_raw]*mat_predictor[pos_raw,3]
+      tab_traj$slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2] + coef.PMM[1*length(var.all2)+length(var.last.level2) + 2 + pos_raw]*mat_predictor[pos_raw,2]
+      tab_traj$slope2      = coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3] + coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3 + pos_raw]*mat_predictor[pos_raw,3]
 
-      if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==F){
+      if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==F){
 
-        tab_traj$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]+
-          coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw]*mat_predictor[pos_raw,4]
+        tab_traj$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]+
+          coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw]*mat_predictor[pos_raw,4]
 
-      } else if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==T){
+      } else if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==T){
 
-        tab_traj$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]
+        tab_traj$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]
 
       }
 
@@ -592,17 +594,17 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
       tab_traj_group0 = data.frame(time = seq(min_plot, max_plot, 0.1), transition = 2)
       ##
       tab_traj_group0$last.level  = coef.PMM[1] + coef.PMM[1+pos_raw]*mat_predictor[pos_raw,1]*bound[1]
-      tab_traj_group0$slope1      = coef.PMM[1*length(var.all)+length(var.last.level) + 2] + coef.PMM[1*length(var.all)+length(var.last.level) + 2 + pos_raw]*mat_predictor[pos_raw,2]*bound[1]
-      tab_traj_group0$slope2      = coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3] + coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3 + pos_raw]*mat_predictor[pos_raw,3]*bound[1]
+      tab_traj_group0$slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2] + coef.PMM[1*length(var.all2)+length(var.last.level2) + 2 + pos_raw]*mat_predictor[pos_raw,2]*bound[1]
+      tab_traj_group0$slope2      = coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3] + coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3 + pos_raw]*mat_predictor[pos_raw,3]*bound[1]
 
-      if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==F){
+      if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==F){
 
-        tab_traj_group0$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]+
-          coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw]*mat_predictor[pos_raw,4]*bound[1]
+        tab_traj_group0$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]+
+          coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw]*mat_predictor[pos_raw,4]*bound[1]
 
-      } else if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==T){
+      } else if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==T){
 
-        tab_traj_group0$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]
+        tab_traj_group0$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]
 
       }
 
@@ -623,17 +625,17 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
       tab_traj_group1 = data.frame(time = seq(min_plot, max_plot, 0.1), transition = 2)
       ##
       tab_traj_group1$last.level  = coef.PMM[1] + coef.PMM[1+pos_raw]*mat_predictor[pos_raw,1]*bound[2]
-      tab_traj_group1$slope1      = coef.PMM[1*length(var.all)+length(var.last.level) + 2] + coef.PMM[1*length(var.all)+length(var.last.level) + 2 + pos_raw]*mat_predictor[pos_raw,2]*bound[2]
-      tab_traj_group1$slope2      = coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3] + coef.PMM[2*length(var.all)+length(var.last.level)+length(var.slope1) + 3 + pos_raw]*mat_predictor[pos_raw,3]*bound[2]
+      tab_traj_group1$slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2] + coef.PMM[1*length(var.all2)+length(var.last.level2) + 2 + pos_raw]*mat_predictor[pos_raw,2]*bound[2]
+      tab_traj_group1$slope2      = coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3] + coef.PMM[2*length(var.all2)+length(var.last.level2)+length(var.slope1_2) + 3 + pos_raw]*mat_predictor[pos_raw,3]*bound[2]
 
-      if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==F){
+      if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==F){
 
-        tab_traj_group1$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]+
-          coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw]*mat_predictor[pos_raw,4]*bound[2]
+        tab_traj_group1$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]+
+          coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw]*mat_predictor[pos_raw,4]*bound[2]
 
-      } else if (is.na(coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4 + pos_raw])==T){
+      } else if (is.na(coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4 + pos_raw])==T){
 
-        tab_traj_group1$changepoint = coef.PMM[3*length(var.all)+length(var.last.level)+length(var.slope1)+length(var.slope2) + 4]
+        tab_traj_group1$changepoint = coef.PMM[3*length(var.all2)+length(var.last.level2)+length(var.slope1_2)+length(var.slope2_2) + 4]
 
       }
 
@@ -675,7 +677,7 @@ nlive.pmma <- function(dataset, ID, outcome, time, var.all = NULL,
     # output
     print(list(model.fit, tab))
     cat("----------------------------------------------------\n The program took", round(cost[3],2), "seconds \n")
-    return(list(model.fit, tab))
+    return(model.fit)
 
 
   }
